# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxo/block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'utxo/block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18utxo/block_message.proto\x12\rutxo_messages\"l\n\x0c\x42lockMessage\x12*\n\x06Header\x18\x01 \x01(\x0b\x32\x1a.utxo_messages.BlockHeader\x12\x30\n\x0cTransactions\x18\x02 \x03(\x0b\x32\x1a.utxo_messages.Transaction\"\xca\x02\n\x0b\x42lockHeader\x12\x0c\n\x04Hash\x18\x01 \x01(\x0c\x12\x15\n\rConfirmations\x18\x02 \x01(\x03\x12\x0c\n\x04Size\x18\x03 \x01(\x05\x12\x14\n\x0cStrippedSize\x18\x04 \x01(\x05\x12\x0e\n\x06Weight\x18\x05 \x01(\x05\x12\x0e\n\x06Height\x18\x06 \x01(\x03\x12\x0f\n\x07Version\x18\x07 \x01(\x05\x12\x12\n\nVersionHex\x18\x08 \x01(\x0c\x12\x12\n\nMerkleRoot\x18\t \x01(\x0c\x12\x0c\n\x04Time\x18\n \x01(\x03\x12\x12\n\nMedianTime\x18\x0b \x01(\x03\x12\r\n\x05Nonce\x18\x0c \x01(\r\x12\x0c\n\x04\x42its\x18\r \x01(\x0c\x12\x12\n\nDifficulty\x18\x0e \x01(\x01\x12\x11\n\tChainwork\x18\x0f \x01(\x0c\x12\x0b\n\x03NTx\x18\x10 \x01(\r\x12\x14\n\x0cPreviousHash\x18\x11 \x01(\x0c\x12\x10\n\x08NextHash\x18\x12 \x01(\x0c\"\xa3\x01\n\x0bTransaction\x12\x30\n\x06Header\x18\x01 \x01(\x0b\x32 .utxo_messages.TransactionHeader\x12/\n\x06Inputs\x18\x02 \x03(\x0b\x32\x1f.utxo_messages.TransactionInput\x12\x31\n\x07Outputs\x18\x03 \x03(\x0b\x32 .utxo_messages.TransactionOutput\"\x8a\x01\n\x11TransactionHeader\x12\x0b\n\x03Hex\x18\x01 \x01(\x0c\x12\n\n\x02Id\x18\x02 \x01(\x0c\x12\x0c\n\x04Hash\x18\x03 \x01(\x0c\x12\x0c\n\x04Size\x18\x04 \x01(\x05\x12\r\n\x05VSize\x18\x05 \x01(\x05\x12\x0e\n\x06Weight\x18\x06 \x01(\x05\x12\x0f\n\x07Version\x18\x07 \x01(\r\x12\x10\n\x08LockTime\x18\x08 \x01(\r\"\x90\x01\n\x10TransactionInput\x12\x10\n\x08\x43oinbase\x18\x01 \x01(\x0c\x12\x0c\n\x04TxId\x18\x02 \x01(\x0c\x12\x0c\n\x04VOut\x18\x03 \x01(\r\x12+\n\tScriptSig\x18\x04 \x01(\x0b\x32\x18.utxo_messages.ScriptSig\x12\x10\n\x08Sequence\x18\x05 \x01(\r\x12\x0f\n\x07Witness\x18\x06 \x03(\t\"%\n\tScriptSig\x12\x0b\n\x03\x41sm\x18\x01 \x01(\t\x12\x0b\n\x03Hex\x18\x02 \x01(\x0c\"`\n\x11TransactionOutput\x12\r\n\x05Value\x18\x01 \x01(\x01\x12\t\n\x01N\x18\x02 \x01(\r\x12\x31\n\x0cScriptPubKey\x18\x03 \x01(\x0b\x32\x1b.utxo_messages.ScriptPubKey\"U\n\x0cScriptPubKey\x12\x0b\n\x03\x41sm\x18\x01 \x01(\t\x12\x0c\n\x04\x44\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03Hex\x18\x03 \x01(\x0c\x12\x0c\n\x04Type\x18\x04 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x05 \x01(\t\"e\n\x1eTransactionOutputWithBlockHash\x12\x30\n\x06Output\x18\x01 \x01(\x0b\x32 .utxo_messages.TransactionOutput\x12\x11\n\tBlockHash\x18\x02 \x01(\x0c\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxo.block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BLOCKMESSAGE']._serialized_start=43
  _globals['_BLOCKMESSAGE']._serialized_end=151
  _globals['_BLOCKHEADER']._serialized_start=154
  _globals['_BLOCKHEADER']._serialized_end=484
  _globals['_TRANSACTION']._serialized_start=487
  _globals['_TRANSACTION']._serialized_end=650
  _globals['_TRANSACTIONHEADER']._serialized_start=653
  _globals['_TRANSACTIONHEADER']._serialized_end=791
  _globals['_TRANSACTIONINPUT']._serialized_start=794
  _globals['_TRANSACTIONINPUT']._serialized_end=938
  _globals['_SCRIPTSIG']._serialized_start=940
  _globals['_SCRIPTSIG']._serialized_end=977
  _globals['_TRANSACTIONOUTPUT']._serialized_start=979
  _globals['_TRANSACTIONOUTPUT']._serialized_end=1075
  _globals['_SCRIPTPUBKEY']._serialized_start=1077
  _globals['_SCRIPTPUBKEY']._serialized_end=1162
  _globals['_TRANSACTIONOUTPUTWITHBLOCKHASH']._serialized_start=1164
  _globals['_TRANSACTIONOUTPUTWITHBLOCKHASH']._serialized_end=1265
# @@protoc_insertion_point(module_scope)
