# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: evm/parsed_abi_block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'evm/parsed_abi_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from evm import block_message_pb2 as evm_dot_block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"evm/parsed_abi_block_message.proto\x12\x0c\x65vm_messages\x1a\x17\x65vm/block_message.proto\"\xe6\x01\n\rArgumentValue\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12\x10\n\x08IsHashed\x18\x02 \x01(\x08\x12\x10\n\x06String\x18\x03 \x01(\tH\x00\x12\x0f\n\x05\x42ytes\x18\x04 \x01(\x0cH\x00\x12\x0e\n\x04UInt\x18\x05 \x01(\x04H\x00\x12\r\n\x03Int\x18\x06 \x01(\x03H\x00\x12\x0e\n\x04\x42ool\x18\x07 \x01(\x08H\x00\x12,\n\x05\x41rray\x18\n \x01(\x0b\x32\x1b.evm_messages.ArgumentArrayH\x00\x12,\n\x05Tuple\x18\x0b \x01(\x0b\x32\x1b.evm_messages.ArgumentTupleH\x00\x42\x07\n\x05Value\">\n\rArgumentArray\x12-\n\x08\x45lements\x18\x01 \x03(\x0b\x32\x1b.evm_messages.ArgumentValue\"L\n\rArgumentTuple\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12-\n\x08\x45lements\x18\x02 \x03(\x0b\x32\x1b.evm_messages.ArgumentValue\"\xfb\x01\n\x12ParsedAbiSignature\x12\x0e\n\x06Parsed\x18\x01 \x01(\x08\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x11\n\tSignature\x18\x03 \x01(\t\x12\x0b\n\x03\x41\x62i\x18\x04 \x01(\t\x12\x15\n\rSignatureHash\x18\x05 \x01(\x0c\x12<\n\x04Type\x18\x06 \x01(\x0e\x32..evm_messages.ParsedAbiSignature.SignatureType\"R\n\rSignatureType\x12\x0c\n\x08\x46UNCTION\x10\x00\x12\x0f\n\x0b\x43ONSTRUCTOR\x10\x01\x12\x0c\n\x08\x46\x41LLBACK\x10\x02\x12\x0b\n\x07RECEIVE\x10\x03\x12\x07\n\x03LOG\x10\x04\"[\n\x0eParsedArgument\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07Indexed\x18\x02 \x01(\x08\x12*\n\x05Value\x18\x03 \x01(\x0b\x32\x1b.evm_messages.ArgumentValue\"\xbd\x01\n\x12ParsedAbiLogHeader\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x12\n\nEnterIndex\x18\x02 \x01(\r\x12\x11\n\tExitIndex\x18\x03 \x01(\r\x12\x19\n\x11LogAfterCallIndex\x18\x04 \x01(\r\x12\n\n\x02Pc\x18\x05 \x01(\x04\x12\x15\n\rSmartContract\x18\x06 \x01(\x0c\x12\x33\n\tSignature\x18\x07 \x01(\x0b\x32 .evm_messages.ParsedAbiSignature\"\xbf\x01\n\x0cParsedAbiLog\x12\'\n\x06Header\x18\x01 \x01(\x0b\x32\x17.evm_messages.LogHeader\x12#\n\x06Topics\x18\x02 \x03(\x0b\x32\x13.evm_messages.Topic\x12\x30\n\x06Parsed\x18\x03 \x01(\x0b\x32 .evm_messages.ParsedAbiLogHeader\x12/\n\tArguments\x18\x04 \x03(\x0b\x32\x1c.evm_messages.ParsedArgument\"\x96\x01\n\x11ParsedStateChange\x12\x12\n\nEnterIndex\x18\x01 \x01(\r\x12\x11\n\tExitIndex\x18\x02 \x01(\r\x12\x1c\n\x14\x43hangeAfterCallIndex\x18\x03 \x01(\r\x12\n\n\x02Pc\x18\x04 \x01(\x04\x12\x0f\n\x07\x41\x64\x64ress\x18\x05 \x01(\x0c\x12\x10\n\x08Location\x18\x06 \x01(\x0c\x12\r\n\x05Value\x18\x07 \x01(\x0c\"\xc4\x03\n\x13ParsedAbiCallHeader\x12\r\n\x05Index\x18\x01 \x01(\r\x12\r\n\x05\x44\x65pth\x18\x02 \x01(\r\x12\x12\n\nEnterIndex\x18\x03 \x01(\r\x12\x11\n\tExitIndex\x18\x04 \x01(\r\x12\x13\n\x0b\x43\x61llerIndex\x18\x05 \x01(\x05\x12\x15\n\rInternalCalls\x18\x06 \x01(\r\x12\x10\n\x08\x43\x61llPath\x18\x07 \x03(\r\x12\x0c\n\x04\x46rom\x18\x08 \x01(\x0c\x12\n\n\x02To\x18\t \x01(\x0c\x12\x0e\n\x06\x43reate\x18\n \x01(\x08\x12\r\n\x05Input\x18\x0b \x01(\x0c\x12\x0b\n\x03Gas\x18\x0c \x01(\x04\x12\r\n\x05Value\x18\r \x01(\x0c\x12\x0e\n\x06Output\x18\x0e \x01(\x0c\x12\x0f\n\x07GasUsed\x18\x0f \x01(\x04\x12\r\n\x05\x45rror\x18\x10 \x01(\t\x12$\n\x06Opcode\x18\x11 \x01(\x0b\x32\x14.evm_messages.Opcode\x12\x14\n\x0cSelfDestruct\x18\x12 \x01(\x08\x12\x11\n\tDelegated\x18\x13 \x01(\x08\x12\x0f\n\x07Success\x18\x14 \x01(\x08\x12\x10\n\x08Reverted\x18\x15 \x01(\x08\x12\x33\n\tSignature\x18\x16 \x01(\x0b\x32 .evm_messages.ParsedAbiSignature\"\x88\x02\n\rParsedAbiCall\x12\x31\n\x06Header\x18\x01 \x01(\x0b\x32!.evm_messages.ParsedAbiCallHeader\x12/\n\tArguments\x18\x02 \x03(\x0b\x32\x1c.evm_messages.ParsedArgument\x12\x32\n\x0cReturnValues\x18\x03 \x03(\x0b\x32\x1c.evm_messages.ParsedArgument\x12(\n\x04Logs\x18\x04 \x03(\x0b\x32\x1a.evm_messages.ParsedAbiLog\x12\x35\n\x0cStateChanges\x18\x05 \x03(\x0b\x32\x1f.evm_messages.ParsedStateChange\"\xa1\x01\n\x0eTransactionFee\x12\x11\n\tSenderFee\x18\x01 \x01(\x0c\x12\x19\n\x11PriorityFeePerGas\x18\x02 \x01(\x0c\x12\x19\n\x11\x45\x66\x66\x65\x63tiveGasPrice\x18\x03 \x01(\x0c\x12\x11\n\tGasRefund\x18\x04 \x01(\x04\x12\r\n\x05\x42urnt\x18\x05 \x01(\x0c\x12\x0f\n\x07Savings\x18\x06 \x01(\x0c\x12\x13\n\x0bMinerReward\x18\x07 \x01(\x0c\"S\n\x1aParsedAbiTransactionStatus\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x10\n\x08\x45ndError\x18\x02 \x01(\t\x12\x12\n\nFaultError\x18\x03 \x01(\t\"\xd9\x02\n\x14ParsedAbiTransaction\x12:\n\x11TransactionHeader\x18\x01 \x01(\x0b\x32\x1f.evm_messages.TransactionHeader\x12\x32\n\rReceiptHeader\x18\x02 \x01(\x0b\x32\x1b.evm_messages.ReceiptHeader\x12\x34\n\x0eTransactionFee\x18\x03 \x01(\x0b\x32\x1c.evm_messages.TransactionFee\x12\x43\n\x11TransactionStatus\x18\x04 \x01(\x0b\x32(.evm_messages.ParsedAbiTransactionStatus\x12*\n\x05\x43\x61lls\x18\x05 \x03(\x0b\x32\x1b.evm_messages.ParsedAbiCall\x12*\n\tSignature\x18\x06 \x01(\x0b\x32\x17.evm_messages.Signature\"\x99\x01\n\x0bMinerReward\x12\r\n\x05Total\x18\x01 \x01(\x0c\x12\x0e\n\x06Static\x18\x02 \x01(\x0c\x12\x0f\n\x07\x44ynamic\x18\x03 \x01(\x0c\x12\x0e\n\x06TxFees\x18\x04 \x01(\x0c\x12\x11\n\tBurntFees\x18\x05 \x01(\x0c\x12\r\n\x05Uncle\x18\x06 \x01(\x0c\x12\x18\n\x0b\x42\x65neficiary\x18\x07 \x01(\x0cH\x00\x88\x01\x01\x42\x0e\n\x0c_Beneficiary\"\x97\x03\n\x15ParsedAbiBlockMessage\x12\"\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x13.evm_messages.Chain\x12)\n\x06Header\x18\x02 \x01(\x0b\x32\x19.evm_messages.BlockHeader\x12)\n\x06Uncles\x18\x03 \x03(\x0b\x32\x19.evm_messages.BlockHeader\x12)\n\x06Reward\x18\x04 \x01(\x0b\x32\x19.evm_messages.MinerReward\x12/\n\x0cUncleRewards\x18\x05 \x03(\x0b\x32\x19.evm_messages.MinerReward\x12\x38\n\x0cTransactions\x18\x06 \x03(\x0b\x32\".evm_messages.ParsedAbiTransaction\x12\x30\n\x08L1Header\x18\x07 \x01(\x0b\x32\x19.evm_messages.BlockHeaderH\x00\x88\x01\x01\x12/\n\x0c\x45xtraRewards\x18\x08 \x03(\x0b\x32\x19.evm_messages.MinerRewardB\x0b\n\t_L1Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'evm.parsed_abi_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ARGUMENTVALUE']._serialized_start=78
  _globals['_ARGUMENTVALUE']._serialized_end=308
  _globals['_ARGUMENTARRAY']._serialized_start=310
  _globals['_ARGUMENTARRAY']._serialized_end=372
  _globals['_ARGUMENTTUPLE']._serialized_start=374
  _globals['_ARGUMENTTUPLE']._serialized_end=450
  _globals['_PARSEDABISIGNATURE']._serialized_start=453
  _globals['_PARSEDABISIGNATURE']._serialized_end=704
  _globals['_PARSEDABISIGNATURE_SIGNATURETYPE']._serialized_start=622
  _globals['_PARSEDABISIGNATURE_SIGNATURETYPE']._serialized_end=704
  _globals['_PARSEDARGUMENT']._serialized_start=706
  _globals['_PARSEDARGUMENT']._serialized_end=797
  _globals['_PARSEDABILOGHEADER']._serialized_start=800
  _globals['_PARSEDABILOGHEADER']._serialized_end=989
  _globals['_PARSEDABILOG']._serialized_start=992
  _globals['_PARSEDABILOG']._serialized_end=1183
  _globals['_PARSEDSTATECHANGE']._serialized_start=1186
  _globals['_PARSEDSTATECHANGE']._serialized_end=1336
  _globals['_PARSEDABICALLHEADER']._serialized_start=1339
  _globals['_PARSEDABICALLHEADER']._serialized_end=1791
  _globals['_PARSEDABICALL']._serialized_start=1794
  _globals['_PARSEDABICALL']._serialized_end=2058
  _globals['_TRANSACTIONFEE']._serialized_start=2061
  _globals['_TRANSACTIONFEE']._serialized_end=2222
  _globals['_PARSEDABITRANSACTIONSTATUS']._serialized_start=2224
  _globals['_PARSEDABITRANSACTIONSTATUS']._serialized_end=2307
  _globals['_PARSEDABITRANSACTION']._serialized_start=2310
  _globals['_PARSEDABITRANSACTION']._serialized_end=2655
  _globals['_MINERREWARD']._serialized_start=2658
  _globals['_MINERREWARD']._serialized_end=2811
  _globals['_PARSEDABIBLOCKMESSAGE']._serialized_start=2814
  _globals['_PARSEDABIBLOCKMESSAGE']._serialized_end=3221
# @@protoc_insertion_point(module_scope)