# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: price_index.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'price_index.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import marketdata_pb2 as marketdata__pb2



DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11price_index.proto\x12\x0bprice_index\x1a\x10marketdata.proto\"4\n\x08\x43urrency\x12\n\n\x02Id\x18\x01 \x01(\t\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0e\n\x06Symbol\x18\x03 \x01(\t\"\x93\x01\n\x06Market\x12\n\n\x02Id\x18\x01 \x01(\t\x12\x0f\n\x07Network\x18\x02 \x01(\t\x12\x12\n\nNetworkBid\x18\x03 \x01(\t\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x05 \x01(\t\x12\x10\n\x08Protocol\x18\x06 \x01(\t\x12\x16\n\x0eProtocolFamily\x18\x07 \x01(\t\x12\x0f\n\x07Program\x18\x08 \x01(\t\"P\n\x07\x41mounts\x12\x0c\n\x04\x42\x61se\x18\x01 \x01(\x02\x12\r\n\x05Quote\x18\x02 \x01(\x02\x12\x0b\n\x03Usd\x18\x03 \x01(\x02\x12\x1b\n\x13\x42\x61seAttributedToUsd\x18\x04 \x01(\x02\"\\\n\x05Quote\x12,\n\rQuoteCurrency\x18\x01 \x01(\x0b\x32\x15.price_index.Currency\x12%\n\x07\x41mounts\x18\x02 \x01(\x0b\x32\x14.price_index.Amounts\"<\n\x0cTimeInterval\x12\x10\n\x08\x44uration\x18\x01 \x01(\r\x12\r\n\x05Start\x18\x02 \x01(\r\x12\x0b\n\x03\x45nd\x18\x03 \x01(\r\"N\n\x04Ohlc\x12\x0c\n\x04Open\x18\x01 \x01(\x02\x12\r\n\x05\x43lose\x18\x02 \x01(\x02\x12\x0c\n\x04High\x18\x03 \x01(\x02\x12\x0b\n\x03Low\x18\x04 \x01(\x02\x12\x0e\n\x06Volume\x18\x05 \x01(\x02\"\x85\x02\n\x13PriceByTimeInterval\x12/\n\x0cTimeInterval\x18\x01 \x01(\x0b\x32\x19.price_index.TimeInterval\x12%\n\x07\x41mounts\x18\x02 \x01(\x0b\x32\x14.price_index.Amounts\x12\x11\n\tMeanPrice\x18\x03 \x01(\x02\x12\x1b\n\x13SimpleMovingAverage\x18\x04 \x01(\x02\x12#\n\x1bWeightedSimpleMovingAverage\x18\x05 \x01(\x02\x12 \n\x18\x45xponentialMovingAverage\x18\x06 \x01(\x02\x12\x1f\n\x04Ohlc\x18\x07 \x01(\x0b\x32\x11.price_index.Ohlc\"\x90\x01\n\rPriceByVolume\x12\x14\n\x0cTargetVolume\x18\x01 \x01(\x02\x12/\n\x0cTimeInterval\x18\x02 \x01(\x0b\x32\x19.price_index.TimeInterval\x12%\n\x07\x41mounts\x18\x03 \x01(\x0b\x32\x14.price_index.Amounts\x12\x11\n\tMeanPrice\x18\x04 \x01(\x02\"(\n\x0f\x45stimatedPrices\x12\x15\n\rAdaptivePrice\x18\x01 \x01(\x02\"\xd6\x01\n\x0bPriceUpdate\x12\"\n\x06Quotes\x18\x01 \x03(\x0b\x32\x12.price_index.Quote\x12>\n\x14PriceByTimeIntervals\x18\x02 \x03(\x0b\x32 .price_index.PriceByTimeInterval\x12\x32\n\x0ePriceByVolumes\x18\x03 \x03(\x0b\x32\x1a.price_index.PriceByVolume\x12/\n\tEstimates\x18\x04 \x01(\x0b\x32\x1c.price_index.EstimatedPrices\"h\n\x0e\x43urrencyUpdate\x12\'\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x15.price_index.Currency\x12-\n\x0bPriceUpdate\x18\x02 \x01(\x0b\x32\x18.price_index.PriceUpdate\"\x88\x01\n\x0bTokenUpdate\x12\'\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x15.price_index.Currency\x12!\n\x05Token\x18\x02 \x01(\x0b\x32\x12.price_index.Token\x12-\n\x0bPriceUpdate\x18\x03 \x01(\x0b\x32\x18.price_index.PriceUpdate\"\xbe\x02\n\nPairUpdate\x12\'\n\x08\x43urrency\x18\x01 \x01(\x0b\x32\x15.price_index.Currency\x12,\n\rQuoteCurrency\x18\x02 \x01(\x0b\x32\x15.price_index.Currency\x12!\n\x05Token\x18\x03 \x01(\x0b\x32\x12.price_index.Token\x12&\n\nQuoteToken\x18\x04 \x01(\x0b\x32\x12.price_index.Token\x12#\n\x06Market\x18\x05 \x01(\x0b\x32\x13.price_index.Market\x12-\n\x0bPriceUpdate\x18\x06 \x01(\x0b\x32\x18.price_index.PriceUpdate\x12:\n\x18PriceUpdateInQuoteTokens\x18\x07 \x01(\x0b\x32\x18.price_index.PriceUpdate\"\xb5\x01\n\x11PriceIndexMessage\x12\x0c\n\x04Time\x18\x01 \x01(\x04\x12\x34\n\x0f\x43urrencyUpdates\x18\x02 \x03(\x0b\x32\x1b.price_index.CurrencyUpdate\x12.\n\x0cTokenUpdates\x18\x03 \x03(\x0b\x32\x18.price_index.TokenUpdate\x12,\n\x0bPairUpdates\x18\x04 \x03(\x0b\x32\x17.price_index.PairUpdateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'price_index_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CURRENCY']._serialized_start=52
  _globals['_CURRENCY']._serialized_end=104
  _globals['_MARKET']._serialized_start=107
  _globals['_MARKET']._serialized_end=254
  _globals['_AMOUNTS']._serialized_start=256
  _globals['_AMOUNTS']._serialized_end=336
  _globals['_QUOTE']._serialized_start=338
  _globals['_QUOTE']._serialized_end=430
  _globals['_TIMEINTERVAL']._serialized_start=432
  _globals['_TIMEINTERVAL']._serialized_end=492
  _globals['_OHLC']._serialized_start=494
  _globals['_OHLC']._serialized_end=572
  _globals['_PRICEBYTIMEINTERVAL']._serialized_start=575
  _globals['_PRICEBYTIMEINTERVAL']._serialized_end=836
  _globals['_PRICEBYVOLUME']._serialized_start=839
  _globals['_PRICEBYVOLUME']._serialized_end=983
  _globals['_ESTIMATEDPRICES']._serialized_start=985
  _globals['_ESTIMATEDPRICES']._serialized_end=1025
  _globals['_PRICEUPDATE']._serialized_start=1028
  _globals['_PRICEUPDATE']._serialized_end=1242
  _globals['_CURRENCYUPDATE']._serialized_start=1244
  _globals['_CURRENCYUPDATE']._serialized_end=1348
  _globals['_TOKENUPDATE']._serialized_start=1351
  _globals['_TOKENUPDATE']._serialized_end=1487
  _globals['_PAIRUPDATE']._serialized_start=1490
  _globals['_PAIRUPDATE']._serialized_end=1808
  _globals['_PRICEINDEXMESSAGE']._serialized_start=1811
  _globals['_PRICEINDEXMESSAGE']._serialized_end=1992
# @@protoc_insertion_point(module_scope)
