# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: solana/ohlc_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'solana/ohlc_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from solana import token_block_message_pb2 as solana_dot_token__block__message__pb2
from solana import dex_block_message_pb2 as solana_dot_dex__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19solana/ohlc_message.proto\x12\x0fsolana_messages\x1a solana/token_block_message.proto\x1a\x1esolana/dex_block_message.proto\"N\n\x0eOhlcDescriptor\x12\x12\n\nPeriodMsec\x18\x01 \x01(\x05\x12\x11\n\tDelayMsec\x18\x02 \x01(\x05\x12\x15\n\rTimestampMsec\x18\x03 \x01(\x03\"e\n\x13OhlcPairTradeAmount\x12\x12\n\nBaseAmount\x18\x01 \x01(\x04\x12\x13\n\x0bQuoteAmount\x18\x02 \x01(\x04\x12%\n\x03\x44\x65x\x18\x03 \x01(\x0b\x32\x18.solana_messages.DexInfo\"\xf4\x01\n\x08OhlcPair\x12\'\n\x04\x42\x61se\x18\x01 \x01(\x0b\x32\x19.solana_messages.Currency\x12(\n\x05Quote\x18\x02 \x01(\x0b\x32\x19.solana_messages.Currency\x12\x12\n\nBaseAmount\x18\x03 \x01(\x04\x12\x13\n\x0bQuoteAmount\x18\x04 \x01(\x04\x12\x0c\n\x04High\x18\x05 \x01(\x02\x12\x0b\n\x03Low\x18\x06 \x01(\x02\x12\x0c\n\x04Open\x18\x07 \x01(\x02\x12\r\n\x05\x43lose\x18\x08 \x01(\x02\x12\x34\n\x06Trades\x18\t \x03(\x0b\x32$.solana_messages.OhlcPairTradeAmount\"k\n\x0bOhlcMessage\x12\x33\n\nDescriptor\x18\x01 \x01(\x0b\x32\x1f.solana_messages.OhlcDescriptor\x12\'\n\x04Pair\x18\x02 \x03(\x0b\x32\x19.solana_messages.OhlcPairb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'solana.ohlc_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_OHLCDESCRIPTOR']._serialized_start=112
  _globals['_OHLCDESCRIPTOR']._serialized_end=190
  _globals['_OHLCPAIRTRADEAMOUNT']._serialized_start=192
  _globals['_OHLCPAIRTRADEAMOUNT']._serialized_end=293
  _globals['_OHLCPAIR']._serialized_start=296
  _globals['_OHLCPAIR']._serialized_end=540
  _globals['_OHLCMESSAGE']._serialized_start=542
  _globals['_OHLCMESSAGE']._serialized_end=649
# @@protoc_insertion_point(module_scope)
