# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: evm/block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'evm/block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65vm/block_message.proto\x12\x0c\x65vm_messages\";\n\x0b\x41\x64\x64ressCode\x12\x0c\n\x04Hash\x18\x01 \x01(\x0c\x12\x0c\n\x04Size\x18\x02 \x01(\x05\x12\x10\n\x08Suicided\x18\x03 \x01(\x08\"\xdf\x03\n\x0b\x42lockHeader\x12\x0c\n\x04Hash\x18\x01 \x01(\x0c\x12\x12\n\nParentHash\x18\x02 \x01(\x0c\x12\x11\n\tUncleHash\x18\x03 \x01(\x0c\x12\x0c\n\x04Root\x18\x04 \x01(\x0c\x12\x0e\n\x06TxHash\x18\x05 \x01(\x0c\x12\x13\n\x0bReceiptHash\x18\x06 \x01(\x0c\x12\x11\n\tMixDigest\x18\x07 \x01(\x0c\x12\x10\n\x08\x43oinbase\x18\x08 \x01(\x0c\x12\r\n\x05\x42loom\x18\t \x01(\x0c\x12\r\n\x05\x45xtra\x18\n \x01(\x0c\x12\r\n\x05Nonce\x18\x0b \x01(\x04\x12\x12\n\nDifficulty\x18\x0c \x01(\x0c\x12\x0e\n\x06Number\x18\r \x01(\x0c\x12\x10\n\x08GasLimit\x18\x0e \x01(\x04\x12\x0f\n\x07GasUsed\x18\x0f \x01(\x04\x12\x0c\n\x04Time\x18\x10 \x01(\x04\x12\x0f\n\x07\x42\x61seFee\x18\x11 \x01(\x0c\x12\x1b\n\x0eSequenceNumber\x18\x12 \x01(\x04H\x00\x88\x01\x01\x12\x18\n\x0b\x42\x61tcherAddr\x18\x13 \x01(\x0cH\x01\x88\x01\x01\x12\x1a\n\rL1FeeOverhead\x18\x14 \x01(\x0cH\x02\x88\x01\x01\x12\x18\n\x0bL1FeeScalar\x18\x15 \x01(\x0cH\x03\x88\x01\x01\x42\x11\n\x0f_SequenceNumberB\x0e\n\x0c_BatcherAddrB\x10\n\x0e_L1FeeOverheadB\x0e\n\x0c_L1FeeScalar\"*\n\x0b\x42lockResult\x12\x0b\n\x03Gas\x18\x01 \x01(\x04\x12\x0e\n\x06\x45rrors\x18\x02 \x01(\t\",\n\tSignature\x12\t\n\x01R\x18\x01 \x01(\x0c\x12\t\n\x01V\x18\x02 \x01(\x0c\x12\t\n\x01S\x18\x03 \x01(\x0c\"$\n\x05Topic\x12\r\n\x05Index\x18\x01 \x01(\x04\x12\x0c\n\x04Hash\x18\x02 \x01(\x0c\"\x9e\x01\n\tLogHeader\x12\r\n\x05Index\x18\x01 \x01(\x04\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\x0c\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c\x12\x0f\n\x07Removed\x18\x04 \x01(\x08\x12.\n\x0b\x41\x64\x64ressCode\x18\x05 \x01(\x0b\x32\x19.evm_messages.AddressCode\x12\x15\n\x08IsSystem\x18\x06 \x01(\x08H\x00\x88\x01\x01\x42\x0b\n\t_IsSystem\"V\n\x03Log\x12*\n\tLogHeader\x18\x01 \x01(\x0b\x32\x17.evm_messages.LogHeader\x12#\n\x06Topics\x18\x02 \x03(\x0b\x32\x13.evm_messages.Topic\"9\n\x05Store\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x10\n\x08Location\x18\x02 \x01(\x0c\x12\r\n\x05Value\x18\x03 \x01(\x0c\"\x92\x03\n\rReceiptHeader\x12\r\n\x05\x42loom\x18\x01 \x01(\x0c\x12\x0f\n\x07GasUsed\x18\x02 \x01(\x04\x12\x0c\n\x04Type\x18\x03 \x01(\r\x12\x17\n\x0f\x43ontractAddress\x18\x04 \x01(\x0c\x12\x19\n\x11\x43umulativeGasUsed\x18\x05 \x01(\x04\x12\x11\n\tPostState\x18\x06 \x01(\x0c\x12\x0e\n\x06Status\x18\x07 \x01(\x04\x12\x36\n\x13\x43ontractAddressCode\x18\x08 \x01(\x0b\x32\x19.evm_messages.AddressCode\x12\x31\n\x02L1\x18\t \x01(\x0b\x32 .evm_messages.ReceiptL1ExtensionH\x00\x88\x01\x01\x12\x1e\n\x11\x45\x66\x66\x65\x63tiveGasPrice\x18\n \x01(\x0cH\x01\x88\x01\x01\x12\x18\n\x0b\x42lobGasUsed\x18\x0b \x01(\x04H\x02\x88\x01\x01\x12\x19\n\x0c\x42lobGasPrice\x18\x0c \x01(\x0cH\x03\x88\x01\x01\x42\x05\n\x03_L1B\x14\n\x12_EffectiveGasPriceB\x0e\n\x0c_BlobGasUsedB\x0f\n\r_BlobGasPrice\"D\n\x12ReceiptL1Extension\x12\x10\n\x08GasPrice\x18\x01 \x01(\x0c\x12\x0f\n\x07GasUsed\x18\x02 \x01(\x0c\x12\x0b\n\x03\x46\x65\x65\x18\x03 \x01(\x0c\"^\n\x07Receipt\x12\x32\n\rReceiptHeader\x18\x01 \x01(\x0b\x32\x1b.evm_messages.ReceiptHeader\x12\x1f\n\x04Logs\x18\x02 \x03(\x0b\x32\x11.evm_messages.Log\"$\n\x06Opcode\x12\x0c\n\x04\x43ode\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\"\xb0\x01\n\x0c\x43\x61ptureStart\x12\x0c\n\x04\x46rom\x18\x01 \x01(\x0c\x12\n\n\x02To\x18\x02 \x01(\x0c\x12\x0e\n\x06\x43reate\x18\x03 \x01(\x08\x12\r\n\x05Input\x18\x04 \x01(\x0c\x12\x0b\n\x03Gas\x18\x05 \x01(\x04\x12\r\n\x05Value\x18\x06 \x01(\x0c\x12)\n\x06ToCode\x18\x07 \x01(\x0b\x32\x19.evm_messages.AddressCode\x12\x14\n\x07TokenId\x18\x08 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_TokenId\"<\n\nCaptureEnd\x12\x0e\n\x06Output\x18\x01 \x01(\x0c\x12\x0f\n\x07GasUsed\x18\x02 \x01(\x04\x12\r\n\x05\x45rror\x18\x03 \x01(\t\"r\n\x08\x43ontract\x12\x15\n\rCallerAddress\x18\x01 \x01(\x0c\x12\x0e\n\x06\x43\x61ller\x18\x02 \x01(\x0c\x12\x0f\n\x07\x41\x64\x64ress\x18\x03 \x01(\x0c\x12\x10\n\x08\x43odeAddr\x18\x04 \x01(\x0c\x12\r\n\x05Input\x18\x05 \x01(\x0c\x12\r\n\x05Value\x18\x06 \x01(\x0c\"\xc2\x01\n\x0c\x43\x61ptureFault\x12\n\n\x02Pc\x18\x01 \x01(\x04\x12$\n\x06Opcode\x18\x02 \x01(\x0b\x32\x14.evm_messages.Opcode\x12\x0b\n\x03Gas\x18\x03 \x01(\x04\x12\x0c\n\x04\x43ost\x18\x04 \x01(\x04\x12\x0e\n\x06Memory\x18\x05 \x01(\x0c\x12\r\n\x05\x44\x65pth\x18\x06 \x01(\x04\x12\r\n\x05Stack\x18\x07 \x03(\x0c\x12(\n\x08\x43ontract\x18\x08 \x01(\x0b\x32\x16.evm_messages.Contract\x12\r\n\x05\x45rror\x18\t \x01(\t\"\xc6\x01\n\x0c\x43\x61ptureEnter\x12$\n\x06Opcode\x18\x01 \x01(\x0b\x32\x14.evm_messages.Opcode\x12\x0c\n\x04\x46rom\x18\x02 \x01(\x0c\x12\n\n\x02To\x18\x03 \x01(\x0c\x12\r\n\x05Input\x18\x04 \x01(\x0c\x12\x0b\n\x03Gas\x18\x05 \x01(\x04\x12\r\n\x05Value\x18\x06 \x01(\x0c\x12)\n\x06ToCode\x18\x07 \x01(\x0b\x32\x19.evm_messages.AddressCode\x12\x14\n\x07TokenId\x18\x08 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_TokenId\"=\n\x0b\x43\x61ptureExit\x12\x0e\n\x06Output\x18\x01 \x01(\x0c\x12\x0f\n\x07GasUsed\x18\x02 \x01(\x04\x12\r\n\x05\x45rror\x18\x03 \x01(\t\"\xd3\x01\n\x12\x43\x61ptureStateHeader\x12\x12\n\nEnterIndex\x18\x01 \x01(\r\x12\x11\n\tExitIndex\x18\x02 \x01(\r\x12\n\n\x02Pc\x18\x03 \x01(\x04\x12$\n\x06Opcode\x18\x04 \x01(\x0b\x32\x14.evm_messages.Opcode\x12\x0b\n\x03Gas\x18\x05 \x01(\x04\x12\x0c\n\x04\x43ost\x18\x06 \x01(\x04\x12\r\n\x05RData\x18\x07 \x01(\x0c\x12\r\n\x05\x44\x65pth\x18\x08 \x01(\x04\x12\r\n\x05\x45rror\x18\t \x01(\t\x12\x12\n\x05Index\x18\n \x01(\rH\x00\x88\x01\x01\x42\x08\n\x06_Index\"\x90\x01\n\x0c\x43\x61ptureState\x12<\n\x12\x43\x61ptureStateHeader\x18\x01 \x01(\x0b\x32 .evm_messages.CaptureStateHeader\x12\x1e\n\x03Log\x18\x02 \x01(\x0b\x32\x11.evm_messages.Log\x12\"\n\x05Store\x18\x03 \x01(\x0b\x32\x13.evm_messages.Store\"\xf5\x01\n\x04\x43\x61ll\x12\r\n\x05Index\x18\x01 \x01(\r\x12\r\n\x05\x44\x65pth\x18\x02 \x01(\r\x12\x12\n\nEnterIndex\x18\x03 \x01(\r\x12\x11\n\tExitIndex\x18\x04 \x01(\r\x12\x13\n\x0b\x43\x61llerIndex\x18\x05 \x01(\x05\x12\x30\n\x0c\x43\x61ptureEnter\x18\x06 \x01(\x0b\x32\x1a.evm_messages.CaptureEnter\x12.\n\x0b\x43\x61ptureExit\x18\x07 \x01(\x0b\x32\x19.evm_messages.CaptureExit\x12\x31\n\rCaptureStates\x18\x08 \x03(\x0b\x32\x1a.evm_messages.CaptureState\"\xef\x01\n\x05Trace\x12!\n\x05\x43\x61lls\x18\x01 \x03(\x0b\x32\x12.evm_messages.Call\x12\x30\n\x0c\x43\x61ptureStart\x18\x02 \x01(\x0b\x32\x1a.evm_messages.CaptureStart\x12,\n\nCaptureEnd\x18\x03 \x01(\x0b\x32\x18.evm_messages.CaptureEnd\x12\x30\n\x0c\x43\x61ptureFault\x18\x04 \x01(\x0b\x32\x1a.evm_messages.CaptureFault\x12\x31\n\rCaptureStates\x18\x05 \x03(\x0b\x32\x1a.evm_messages.CaptureState\"3\n\x0b\x41\x63\x63\x65ssTuple\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x13\n\x0bStorageKeys\x18\x02 \x03(\x0c\"\xbf\x04\n\x11TransactionHeader\x12\r\n\x05Index\x18\x01 \x01(\x04\x12\x0c\n\x04Hash\x18\x02 \x01(\x0c\x12\x0b\n\x03Gas\x18\x03 \x01(\x04\x12\r\n\x05Value\x18\x04 \x01(\x0c\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\x12\r\n\x05Nonce\x18\x06 \x01(\x04\x12\x0f\n\x07\x43hainId\x18\x07 \x01(\x0c\x12\x0c\n\x04\x43ost\x18\x08 \x01(\x0c\x12\x11\n\tGasFeeCap\x18\t \x01(\x0c\x12\x10\n\x08GasPrice\x18\n \x01(\x0c\x12\x11\n\tGasTipCap\x18\x0b \x01(\x0c\x12\x11\n\tProtected\x18\x0c \x01(\x08\x12\x0c\n\x04Type\x18\r \x01(\r\x12\n\n\x02To\x18\x0e \x01(\x0c\x12\x0c\n\x04\x46rom\x18\x0f \x01(\x0c\x12)\n\x06ToCode\x18\x10 \x01(\x0b\x32\x19.evm_messages.AddressCode\x12-\n\nAccessList\x18\x11 \x03(\x0b\x32\x19.evm_messages.AccessTuple\x12\x12\n\x05GasL1\x18\x12 \x01(\x04H\x00\x88\x01\x01\x12\x17\n\nIsSystemTx\x18\x13 \x01(\x08H\x01\x88\x01\x01\x12\x1b\n\x0e\x45\x66\x66\x65\x63tiveNonce\x18\x14 \x01(\x04H\x02\x88\x01\x01\x12\x17\n\nSourceHash\x18\x15 \x01(\x0cH\x03\x88\x01\x01\x12\x11\n\x04Time\x18\x16 \x01(\x04H\x04\x88\x01\x01\x12%\n\x04\x42lob\x18\x17 \x01(\x0b\x32\x12.evm_messages.BlobH\x05\x88\x01\x01\x42\x08\n\x06_GasL1B\r\n\x0b_IsSystemTxB\x11\n\x0f_EffectiveNonceB\r\n\x0b_SourceHashB\x07\n\x05_TimeB\x07\n\x05_Blob\"c\n\x04\x42lob\x12\x0e\n\x06Hashes\x18\x01 \x03(\x0c\x12\x0e\n\x06Proofs\x18\x02 \x03(\x0c\x12\x13\n\x0b\x43ommitments\x18\x03 \x03(\x0c\x12\x0f\n\x07\x42lobGas\x18\x04 \x01(\x04\x12\x15\n\rBlobGasFeeCap\x18\x05 \x01(\x0c\"\xd3\x01\n\x0bTransaction\x12:\n\x11TransactionHeader\x18\x01 \x01(\x0b\x32\x1f.evm_messages.TransactionHeader\x12*\n\tSignature\x18\x02 \x01(\x0b\x32\x17.evm_messages.Signature\x12&\n\x07Receipt\x18\x03 \x01(\x0b\x32\x15.evm_messages.Receipt\x12\"\n\x05Trace\x18\x04 \x01(\x0b\x32\x13.evm_messages.Trace\x12\x10\n\x04Time\x18\x05 \x01(\x04\x42\x02\x18\x01\"(\n\x05\x43hain\x12\x0f\n\x07\x43hainId\x18\x01 \x01(\x0c\x12\x0e\n\x06\x43onfig\x18\x02 \x01(\t\"\xa1\x01\n\rL1MessageInfo\x12\x0c\n\x04Kind\x18\x01 \x01(\r\x12\x0e\n\x06Poster\x18\x02 \x01(\x0c\x12\x13\n\x0b\x42lockNumber\x18\x03 \x01(\x04\x12\x11\n\tTimestamp\x18\x04 \x01(\x04\x12\x16\n\tRequestId\x18\x05 \x01(\x0cH\x00\x88\x01\x01\x12\x16\n\tL1BaseFee\x18\x06 \x01(\x0cH\x01\x88\x01\x01\x42\x0c\n\n_RequestIdB\x0c\n\n_L1BaseFee\"\xee\x02\n\x0c\x42lockMessage\x12\"\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x13.evm_messages.Chain\x12)\n\x06Header\x18\x02 \x01(\x0b\x32\x19.evm_messages.BlockHeader\x12)\n\x06Result\x18\x03 \x01(\x0b\x32\x19.evm_messages.BlockResult\x12)\n\x06Uncles\x18\x04 \x03(\x0b\x32\x19.evm_messages.BlockHeader\x12/\n\x0cTransactions\x18\x05 \x03(\x0b\x32\x19.evm_messages.Transaction\x12\x30\n\x08L1Header\x18\x06 \x01(\x0b\x32\x19.evm_messages.BlockHeaderH\x00\x88\x01\x01\x12\x37\n\rL1MessageInfo\x18\x07 \x01(\x0b\x32\x1b.evm_messages.L1MessageInfoH\x01\x88\x01\x01\x42\x0b\n\t_L1HeaderB\x10\n\x0e_L1MessageInfoB \n\x12io.bitquery.protosB\nEvmMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'evm.block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022io.bitquery.protosB\nEvmMessage'
  _globals['_TRANSACTION'].fields_by_name['Time']._loaded_options = None
  _globals['_TRANSACTION'].fields_by_name['Time']._serialized_options = b'\030\001'
  _globals['_ADDRESSCODE']._serialized_start=41
  _globals['_ADDRESSCODE']._serialized_end=100
  _globals['_BLOCKHEADER']._serialized_start=103
  _globals['_BLOCKHEADER']._serialized_end=582
  _globals['_BLOCKRESULT']._serialized_start=584
  _globals['_BLOCKRESULT']._serialized_end=626
  _globals['_SIGNATURE']._serialized_start=628
  _globals['_SIGNATURE']._serialized_end=672
  _globals['_TOPIC']._serialized_start=674
  _globals['_TOPIC']._serialized_end=710
  _globals['_LOGHEADER']._serialized_start=713
  _globals['_LOGHEADER']._serialized_end=871
  _globals['_LOG']._serialized_start=873
  _globals['_LOG']._serialized_end=959
  _globals['_STORE']._serialized_start=961
  _globals['_STORE']._serialized_end=1018
  _globals['_RECEIPTHEADER']._serialized_start=1021
  _globals['_RECEIPTHEADER']._serialized_end=1423
  _globals['_RECEIPTL1EXTENSION']._serialized_start=1425
  _globals['_RECEIPTL1EXTENSION']._serialized_end=1493
  _globals['_RECEIPT']._serialized_start=1495
  _globals['_RECEIPT']._serialized_end=1589
  _globals['_OPCODE']._serialized_start=1591
  _globals['_OPCODE']._serialized_end=1627
  _globals['_CAPTURESTART']._serialized_start=1630
  _globals['_CAPTURESTART']._serialized_end=1806
  _globals['_CAPTUREEND']._serialized_start=1808
  _globals['_CAPTUREEND']._serialized_end=1868
  _globals['_CONTRACT']._serialized_start=1870
  _globals['_CONTRACT']._serialized_end=1984
  _globals['_CAPTUREFAULT']._serialized_start=1987
  _globals['_CAPTUREFAULT']._serialized_end=2181
  _globals['_CAPTUREENTER']._serialized_start=2184
  _globals['_CAPTUREENTER']._serialized_end=2382
  _globals['_CAPTUREEXIT']._serialized_start=2384
  _globals['_CAPTUREEXIT']._serialized_end=2445
  _globals['_CAPTURESTATEHEADER']._serialized_start=2448
  _globals['_CAPTURESTATEHEADER']._serialized_end=2659
  _globals['_CAPTURESTATE']._serialized_start=2662
  _globals['_CAPTURESTATE']._serialized_end=2806
  _globals['_CALL']._serialized_start=2809
  _globals['_CALL']._serialized_end=3054
  _globals['_TRACE']._serialized_start=3057
  _globals['_TRACE']._serialized_end=3296
  _globals['_ACCESSTUPLE']._serialized_start=3298
  _globals['_ACCESSTUPLE']._serialized_end=3349
  _globals['_TRANSACTIONHEADER']._serialized_start=3352
  _globals['_TRANSACTIONHEADER']._serialized_end=3927
  _globals['_BLOB']._serialized_start=3929
  _globals['_BLOB']._serialized_end=4028
  _globals['_TRANSACTION']._serialized_start=4031
  _globals['_TRANSACTION']._serialized_end=4242
  _globals['_CHAIN']._serialized_start=4244
  _globals['_CHAIN']._serialized_end=4284
  _globals['_L1MESSAGEINFO']._serialized_start=4287
  _globals['_L1MESSAGEINFO']._serialized_end=4448
  _globals['_BLOCKMESSAGE']._serialized_start=4451
  _globals['_BLOCKMESSAGE']._serialized_end=4817
# @@protoc_insertion_point(module_scope)
