# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: solana/token_block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'solana/token_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from solana import block_message_pb2 as solana_dot_block__message__pb2
from solana import parsed_idl_block_message_pb2 as solana_dot_parsed__idl__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n solana/token_block_message.proto\x12\x0fsolana_messages\x1a\x1asolana/block_message.proto\x1a%solana/parsed_idl_block_message.proto\"@\n\x0cTokenCreator\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x10\n\x08Verified\x18\x02 \x01(\x08\x12\r\n\x05Share\x18\x03 \x01(\r\"\xbb\x04\n\x08\x43urrency\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x08\x44\x65\x63imals\x18\x02 \x01(\r\x12\x0b\n\x03Uri\x18\x03 \x01(\t\x12\x0e\n\x06Symbol\x18\x04 \x01(\t\x12\x0e\n\x06Native\x18\x05 \x01(\x08\x12\x0f\n\x07Wrapped\x18\x06 \x01(\x08\x12\x10\n\x08\x46ungible\x18\x07 \x01(\x08\x12\x0b\n\x03Key\x18\x08 \x01(\t\x12\x1c\n\x14SellerFeeBasisPoints\x18\t \x01(\r\x12\x19\n\x0c\x45\x64itionNonce\x18\n \x01(\rH\x00\x88\x01\x01\x12\x1a\n\rTokenStandard\x18\x0b \x01(\tH\x01\x88\x01\x01\x12\x16\n\x0eProgramAddress\x18\x0c \x01(\x0c\x12\x13\n\x0bMintAddress\x18\r \x01(\x0c\x12\x17\n\x0fMetadataAddress\x18\x0e \x01(\x0c\x12\x17\n\x0fUpdateAuthority\x18\x0f \x01(\x0c\x12\x19\n\x11\x43ollectionAddress\x18\x10 \x01(\x0c\x12\x1a\n\x12VerifiedCollection\x18\x11 \x01(\x08\x12\x1b\n\x13PrimarySaleHappened\x18\x12 \x01(\x08\x12\x11\n\tIsMutable\x18\x13 \x01(\x08\x12\x34\n\rTokenCreators\x18\x14 \x03(\x0b\x32\x1d.solana_messages.TokenCreator\x12\x17\n\x0f\x46reezeAuthority\x18\x15 \x01(\x0c\x12\x15\n\rMintAuthority\x18\x16 \x01(\x0c\x12\x0e\n\x06Parsed\x18\x17 \x01(\x08\x42\x0f\n\r_EditionNonceB\x10\n\x0e_TokenStandard\"{\n\x15\x43urrencyBalanceUpdate\x12\x35\n\rBalanceUpdate\x18\x01 \x01(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12+\n\x08\x43urrency\x18\x02 \x01(\x0b\x32\x19.solana_messages.Currency\"\xa0\x02\n\x08Transfer\x12\x18\n\x10InstructionIndex\x18\x01 \x01(\r\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x04\x12(\n\x06Sender\x18\x03 \x01(\x0b\x32\x18.solana_messages.Account\x12*\n\x08Receiver\x18\x04 \x01(\x0b\x32\x18.solana_messages.Account\x12+\n\tAuthority\x18\x05 \x01(\x0b\x32\x18.solana_messages.Account\x12+\n\x08\x43urrency\x18\x06 \x01(\x0b\x32\x19.solana_messages.Currency\x12:\n\x0bInstruction\x18\x07 \x01(\x0b\x32%.solana_messages.ParsedIdlInstruction\"\xcc\x02\n\x18InstructionBalanceUpdate\x12\x18\n\x10InstructionIndex\x18\x01 \x01(\r\x12K\n\x1bTotalCurrencyBalanceUpdates\x18\x02 \x03(\x0b\x32&.solana_messages.CurrencyBalanceUpdate\x12I\n\x19OwnCurrencyBalanceUpdates\x18\x03 \x03(\x0b\x32&.solana_messages.CurrencyBalanceUpdate\x12\x42\n\x12TokenSupplyUpdates\x18\x04 \x03(\x0b\x32&.solana_messages.CurrencyBalanceUpdate\x12:\n\x0bInstruction\x18\x05 \x01(\x0b\x32%.solana_messages.ParsedIdlInstruction\"\xde\x02\n\x16ParsedTokenTransaction\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x11\n\tSignature\x18\x02 \x01(\x0c\x12\x32\n\x06Status\x18\x03 \x01(\x0b\x32\".solana_messages.TransactionStatus\x12\x32\n\x06Header\x18\x04 \x01(\x0b\x32\".solana_messages.TransactionHeader\x12,\n\tTransfers\x18\x05 \x03(\x0b\x32\x19.solana_messages.Transfer\x12>\n\x0e\x42\x61lanceUpdates\x18\x06 \x03(\x0b\x32&.solana_messages.CurrencyBalanceUpdate\x12L\n\x19InstructionBalanceUpdates\x18\x07 \x03(\x0b\x32).solana_messages.InstructionBalanceUpdate\"\x80\x01\n\x11TokenBlockMessage\x12,\n\x06Header\x18\x01 \x01(\x0b\x32\x1c.solana_messages.BlockHeader\x12=\n\x0cTransactions\x18\x02 \x03(\x0b\x32\'.solana_messages.ParsedTokenTransactionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'solana.token_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TOKENCREATOR']._serialized_start=120
  _globals['_TOKENCREATOR']._serialized_end=184
  _globals['_CURRENCY']._serialized_start=187
  _globals['_CURRENCY']._serialized_end=758
  _globals['_CURRENCYBALANCEUPDATE']._serialized_start=760
  _globals['_CURRENCYBALANCEUPDATE']._serialized_end=883
  _globals['_TRANSFER']._serialized_start=886
  _globals['_TRANSFER']._serialized_end=1174
  _globals['_INSTRUCTIONBALANCEUPDATE']._serialized_start=1177
  _globals['_INSTRUCTIONBALANCEUPDATE']._serialized_end=1509
  _globals['_PARSEDTOKENTRANSACTION']._serialized_start=1512
  _globals['_PARSEDTOKENTRANSACTION']._serialized_end=1862
  _globals['_TOKENBLOCKMESSAGE']._serialized_start=1865
  _globals['_TOKENBLOCKMESSAGE']._serialized_end=1993
# @@protoc_insertion_point(module_scope)
