# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: marketdata.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'marketdata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10marketdata.proto\x12\x0bprice_index\"Y\n\x11MarketdataMessage\x12\x34\n\nCurrencies\x18\x01 \x03(\x0b\x32 .price_index.CurrencyPriceBucket\x12\x0e\n\x06Source\x18\x02 \x01(\t\"\xb9\x01\n\x05Token\x12\n\n\x02Id\x18\x01 \x01(\t\x12\x0b\n\x03\x44id\x18\x02 \x01(\t\x12\x0f\n\x07Network\x18\x03 \x01(\t\x12\x14\n\x07\x41\x64\x64ress\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07TokenId\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x08IsNative\x18\x06 \x01(\x08\x12\x0c\n\x04Name\x18\x07 \x01(\t\x12\x0e\n\x06Symbol\x18\x08 \x01(\t\x12\x12\n\nNetworkBid\x18\t \x01(\tB\n\n\x08_AddressB\n\n\x08_TokenId\"\x95\x01\n\x13\x43urrencyPriceBucket\x12\"\n\x06Tokens\x18\x01 \x03(\x0b\x32\x12.price_index.Token\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0e\n\x06Symbol\x18\x03 \x01(\t\x12\x12\n\nOriginalId\x18\x04 \x01(\t\x12(\n\x06\x42ucket\x18\x06 \x01(\x0b\x32\x18.price_index.PriceBucket\"\"\n\x05Price\x12\x0c\n\x04Time\x18\x01 \x01(\x04\x12\x0b\n\x03Usd\x18\x02 \x01(\x01\"Z\n\x0bPriceBucket\x12\x10\n\x08Interval\x18\x01 \x01(\r\x12\"\n\x06Prices\x18\x02 \x03(\x0b\x32\x12.price_index.Price\x12\x15\n\rLastUpdatedAt\x18\x03 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'marketdata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MARKETDATAMESSAGE']._serialized_start=33
  _globals['_MARKETDATAMESSAGE']._serialized_end=122
  _globals['_TOKEN']._serialized_start=125
  _globals['_TOKEN']._serialized_end=310
  _globals['_CURRENCYPRICEBUCKET']._serialized_start=313
  _globals['_CURRENCYPRICEBUCKET']._serialized_end=462
  _globals['_PRICE']._serialized_start=464
  _globals['_PRICE']._serialized_end=498
  _globals['_PRICEBUCKET']._serialized_start=500
  _globals['_PRICEBUCKET']._serialized_end=590
# @@protoc_insertion_point(module_scope)
