# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: solana/dex_block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'solana/dex_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from solana import block_message_pb2 as solana_dot_block__message__pb2
from solana import token_block_message_pb2 as solana_dot_token__block__message__pb2
from solana import parsed_idl_block_message_pb2 as solana_dot_parsed__idl__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esolana/dex_block_message.proto\x12\x0fsolana_messages\x1a\x1asolana/block_message.proto\x1a solana/token_block_message.proto\x1a%solana/parsed_idl_block_message.proto\"O\n\x07\x44\x65xInfo\x12\x16\n\x0eProgramAddress\x18\x01 \x01(\x0c\x12\x14\n\x0cProtocolName\x18\x02 \x01(\t\x12\x16\n\x0eProtocolFamily\x18\x03 \x01(\t\"\x85\x01\n\tDexMarket\x12\x15\n\rMarketAddress\x18\x01 \x01(\x0c\x12/\n\x0c\x42\x61seCurrency\x18\x02 \x01(\x0b\x32\x19.solana_messages.Currency\x12\x30\n\rQuoteCurrency\x18\x03 \x01(\x0b\x32\x19.solana_messages.Currency\"\x92\x01\n\x08\x44\x65xOrder\x12\x0f\n\x07OrderId\x18\x01 \x01(\x0c\x12\x0f\n\x07\x42uySide\x18\x02 \x01(\x08\x12\x12\n\nLimitPrice\x18\x03 \x01(\x04\x12\x13\n\x0bLimitAmount\x18\x04 \x01(\x04\x12\x0f\n\x07\x41\x63\x63ount\x18\x05 \x01(\x0c\x12\r\n\x05Owner\x18\x06 \x01(\x0c\x12\r\n\x05Payer\x18\x07 \x01(\x0c\x12\x0c\n\x04Mint\x18\x08 \x01(\x0c\"\xe1\x01\n\x19ParsedPoolLiquidityChange\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x11\n\tSignature\x18\x02 \x01(\x0c\x12\x32\n\x06Status\x18\x03 \x01(\x0b\x32\".solana_messages.TransactionStatus\x12\x32\n\x06Header\x18\x04 \x01(\x0b\x32\".solana_messages.TransactionHeader\x12:\n\x07\x43hanges\x18\x05 \x03(\x0b\x32).solana_messages.PoolLiquidityChangeEvent\"\xa6\x02\n\x18PoolLiquidityChangeEvent\x12\x18\n\x10InstructionIndex\x18\x01 \x01(\r\x12%\n\x03\x44\x65x\x18\x02 \x01(\x0b\x32\x18.solana_messages.DexInfo\x12*\n\x06Market\x18\x03 \x01(\x0b\x32\x1a.solana_messages.DexMarket\x12/\n\x0c\x42\x61seCurrency\x18\x04 \x01(\x0b\x32\x19.solana_messages.PoolSide\x12\x30\n\rQuoteCurrency\x18\x05 \x01(\x0b\x32\x19.solana_messages.PoolSide\x12:\n\x0bInstruction\x18\x06 \x01(\x0b\x32%.solana_messages.ParsedIdlInstruction\"4\n\x08PoolSide\x12\x14\n\x0c\x43hangeAmount\x18\x02 \x01(\x03\x12\x12\n\nPostAmount\x18\x03 \x01(\x04\"\x94\x02\n\rDexOrderEvent\x12\x18\n\x10InstructionIndex\x18\x01 \x01(\r\x12\x30\n\x04Type\x18\x02 \x01(\x0e\x32\".solana_messages.DexOrderEventType\x12%\n\x03\x44\x65x\x18\x03 \x01(\x0b\x32\x18.solana_messages.DexInfo\x12*\n\x06Market\x18\x04 \x01(\x0b\x32\x1a.solana_messages.DexMarket\x12(\n\x05Order\x18\x05 \x01(\x0b\x32\x19.solana_messages.DexOrder\x12:\n\x0bInstruction\x18\x06 \x01(\x0b\x32%.solana_messages.ParsedIdlInstruction\"\xa0\x01\n\x0c\x44\x65xTradeSide\x12\x0e\n\x06\x41mount\x18\x01 \x01(\x04\x12+\n\x08\x43urrency\x18\x02 \x01(\x0b\x32\x19.solana_messages.Currency\x12)\n\x07\x41\x63\x63ount\x18\x03 \x01(\x0b\x32\x18.solana_messages.Account\x12(\n\x05Order\x18\x04 \x01(\x0b\x32\x19.solana_messages.DexOrder\"\xaf\x02\n\rDexTradeEvent\x12\x18\n\x10InstructionIndex\x18\x01 \x01(\r\x12%\n\x03\x44\x65x\x18\x02 \x01(\x0b\x32\x18.solana_messages.DexInfo\x12*\n\x06Market\x18\x03 \x01(\x0b\x32\x1a.solana_messages.DexMarket\x12*\n\x03\x42uy\x18\x04 \x01(\x0b\x32\x1d.solana_messages.DexTradeSide\x12+\n\x04Sell\x18\x05 \x01(\x0b\x32\x1d.solana_messages.DexTradeSide\x12\x0f\n\x07Royalty\x18\x06 \x01(\x04\x12\x0b\n\x03\x46\x65\x65\x18\x07 \x01(\x04\x12:\n\x0bInstruction\x18\x08 \x01(\x0b\x32%.solana_messages.ParsedIdlInstruction\"\xc4\x02\n\x14ParsedDexTransaction\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x11\n\tSignature\x18\x02 \x01(\x0c\x12\x32\n\x06Status\x18\x03 \x01(\x0b\x32\".solana_messages.TransactionStatus\x12\x32\n\x06Header\x18\x04 \x01(\x0b\x32\".solana_messages.TransactionHeader\x12.\n\x06Trades\x18\x05 \x03(\x0b\x32\x1e.solana_messages.DexTradeEvent\x12\x33\n\x0bOrderEvents\x18\x06 \x03(\x0b\x32\x1e.solana_messages.DexOrderEvent\x12=\n\nPoolEvents\x18\x07 \x03(\x0b\x32).solana_messages.PoolLiquidityChangeEvent\"\x82\x01\n\x15\x44\x65xParsedBlockMessage\x12,\n\x06Header\x18\x01 \x01(\x0b\x32\x1c.solana_messages.BlockHeader\x12;\n\x0cTransactions\x18\x02 \x03(\x0b\x32%.solana_messages.ParsedDexTransaction*5\n\x11\x44\x65xOrderEventType\x12\x08\n\x04OPEN\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\n\n\x06\x43\x41NCEL\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'solana.dex_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DEXORDEREVENTTYPE']._serialized_start=2305
  _globals['_DEXORDEREVENTTYPE']._serialized_end=2358
  _globals['_DEXINFO']._serialized_start=152
  _globals['_DEXINFO']._serialized_end=231
  _globals['_DEXMARKET']._serialized_start=234
  _globals['_DEXMARKET']._serialized_end=367
  _globals['_DEXORDER']._serialized_start=370
  _globals['_DEXORDER']._serialized_end=516
  _globals['_PARSEDPOOLLIQUIDITYCHANGE']._serialized_start=519
  _globals['_PARSEDPOOLLIQUIDITYCHANGE']._serialized_end=744
  _globals['_POOLLIQUIDITYCHANGEEVENT']._serialized_start=747
  _globals['_POOLLIQUIDITYCHANGEEVENT']._serialized_end=1041
  _globals['_POOLSIDE']._serialized_start=1043
  _globals['_POOLSIDE']._serialized_end=1095
  _globals['_DEXORDEREVENT']._serialized_start=1098
  _globals['_DEXORDEREVENT']._serialized_end=1374
  _globals['_DEXTRADESIDE']._serialized_start=1377
  _globals['_DEXTRADESIDE']._serialized_end=1537
  _globals['_DEXTRADEEVENT']._serialized_start=1540
  _globals['_DEXTRADEEVENT']._serialized_end=1843
  _globals['_PARSEDDEXTRANSACTION']._serialized_start=1846
  _globals['_PARSEDDEXTRANSACTION']._serialized_end=2170
  _globals['_DEXPARSEDBLOCKMESSAGE']._serialized_start=2173
  _globals['_DEXPARSEDBLOCKMESSAGE']._serialized_end=2303
# @@protoc_insertion_point(module_scope)
