# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: solana/block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'solana/block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asolana/block_message.proto\x12\x0fsolana_messages\"z\n\x07\x41\x63\x63ount\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x10\n\x08IsSigner\x18\x02 \x01(\x08\x12\x12\n\nIsWritable\x18\x03 \x01(\x08\x12.\n\x05Token\x18\x04 \x01(\x0b\x32\x1a.solana_messages.TokenInfoH\x00\x88\x01\x01\x42\x08\n\x06_Token\"S\n\tTokenInfo\x12\x0c\n\x04Mint\x18\x01 \x01(\x0c\x12\r\n\x05Owner\x18\x02 \x01(\x0c\x12\x10\n\x08\x44\x65\x63imals\x18\x03 \x01(\r\x12\x11\n\tProgramId\x18\x04 \x01(\x0cJ\x04\x08\x05\x10\x06\"N\n\rBalanceUpdate\x12\x12\n\nPreBalance\x18\x01 \x01(\x04\x12\x13\n\x0bPostBalance\x18\x02 \x01(\x04\x12\x14\n\x0c\x41\x63\x63ountIndex\x18\x03 \x01(\r\"\xc0\x02\n\x0bInstruction\x12\x1b\n\x13ProgramAccountIndex\x18\x01 \x01(\r\x12\x13\n\x0b\x43\x61llerIndex\x18\x02 \x01(\x04\x12\x12\n\nInnerIndex\x18\x03 \x01(\x04\x12\x14\n\x0cNestingLevel\x18\x04 \x01(\x04\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\x12\x16\n\x0e\x41\x63\x63ountIndexes\x18\x06 \x03(\r\x12\x36\n\x0e\x42\x61lanceUpdates\x18\x07 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12;\n\x13TokenBalanceUpdates\x18\x08 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12:\n\x12TokenSupplyUpdates\x18\t \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\"\x9b\x01\n\x11TransactionHeader\x12\x0b\n\x03\x46\x65\x65\x18\x01 \x01(\x04\x12\x10\n\x08\x46\x65\x65Payer\x18\x02 \x01(\x0c\x12\x17\n\x0fRecentBlockhash\x18\x03 \x01(\x0c\x12\x0e\n\x06Signer\x18\x04 \x01(\x0c\x12\x12\n\nSignatures\x18\x05 \x03(\x0c\x12*\n\x08\x41\x63\x63ounts\x18\x06 \x03(\x0b\x32\x18.solana_messages.Account\"\x83\x01\n\x06Reward\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x03\x12\x13\n\x0bPostBalance\x18\x03 \x01(\x04\x12/\n\nRewardType\x18\x04 \x01(\x0e\x32\x1b.solana_messages.RewardType\x12\x12\n\nCommission\x18\x05 \x01(\x04\":\n\x11TransactionStatus\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x14\n\x0c\x45rrorMessage\x18\x02 \x01(\t\"\xd8\x02\n\x0bTransaction\x12\x11\n\tSignature\x18\x01 \x01(\x0c\x12\x32\n\x06Status\x18\x02 \x01(\x0b\x32\".solana_messages.TransactionStatus\x12\x32\n\x06Header\x18\x03 \x01(\x0b\x32\".solana_messages.TransactionHeader\x12;\n\x13TotalBalanceUpdates\x18\x04 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12@\n\x18TotalTokenBalanceUpdates\x18\x05 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12\x32\n\x0cInstructions\x18\x07 \x03(\x0b\x32\x1c.solana_messages.Instruction\x12\x0c\n\x04Logs\x18\x08 \x03(\t\x12\r\n\x05Index\x18\t \x01(\x04\"t\n\x0b\x42lockHeader\x12\x0c\n\x04Slot\x18\x01 \x01(\x04\x12\x0c\n\x04Hash\x18\x02 \x01(\x0c\x12\x12\n\nParentSlot\x18\x04 \x01(\x04\x12\x0e\n\x06Height\x18\x05 \x01(\x04\x12\x11\n\tTimestamp\x18\x06 \x01(\x03\x12\x12\n\nParentHash\x18\x07 \x01(\x0c\"\x9a\x01\n\x0c\x42lockMessage\x12,\n\x06Header\x18\x01 \x01(\x0b\x32\x1c.solana_messages.BlockHeader\x12(\n\x07Rewards\x18\x02 \x03(\x0b\x32\x17.solana_messages.Reward\x12\x32\n\x0cTransactions\x18\x03 \x03(\x0b\x32\x1c.solana_messages.Transaction*O\n\nRewardType\x12\x15\n\x11RewardTypeUnknown\x10\x00\x12\x07\n\x03\x46\x65\x65\x10\x01\x12\x08\n\x04Rent\x10\x02\x12\x0b\n\x07Staking\x10\x03\x12\n\n\x06Voting\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'solana.block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REWARDTYPE']._serialized_start=1633
  _globals['_REWARDTYPE']._serialized_end=1712
  _globals['_ACCOUNT']._serialized_start=47
  _globals['_ACCOUNT']._serialized_end=169
  _globals['_TOKENINFO']._serialized_start=171
  _globals['_TOKENINFO']._serialized_end=254
  _globals['_BALANCEUPDATE']._serialized_start=256
  _globals['_BALANCEUPDATE']._serialized_end=334
  _globals['_INSTRUCTION']._serialized_start=337
  _globals['_INSTRUCTION']._serialized_end=657
  _globals['_TRANSACTIONHEADER']._serialized_start=660
  _globals['_TRANSACTIONHEADER']._serialized_end=815
  _globals['_REWARD']._serialized_start=818
  _globals['_REWARD']._serialized_end=949
  _globals['_TRANSACTIONSTATUS']._serialized_start=951
  _globals['_TRANSACTIONSTATUS']._serialized_end=1009
  _globals['_TRANSACTION']._serialized_start=1012
  _globals['_TRANSACTION']._serialized_end=1356
  _globals['_BLOCKHEADER']._serialized_start=1358
  _globals['_BLOCKHEADER']._serialized_end=1474
  _globals['_BLOCKMESSAGE']._serialized_start=1477
  _globals['_BLOCKMESSAGE']._serialized_end=1631
# @@protoc_insertion_point(module_scope)
