# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron/block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'tron/block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from evm import block_message_pb2 as evm_dot_block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18tron/block_message.proto\x12\rtron_messages\x1a\x17\x65vm/block_message.proto\"\xc6\x01\n\x11TransactionHeader\x12\x0c\n\x04Hash\x18\x01 \x01(\x0c\x12\x0b\n\x03\x46\x65\x65\x18\x02 \x01(\x03\x12\r\n\x05Index\x18\x03 \x01(\x05\x12\x12\n\nExpiration\x18\x04 \x01(\x03\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\x12\x10\n\x08\x46\x65\x65Limit\x18\x06 \x01(\x03\x12\x11\n\tTimestamp\x18\x07 \x01(\x03\x12\x12\n\nSignatures\x18\x08 \x03(\x0c\x12\x11\n\x04Time\x18\t \x01(\x04H\x00\x88\x01\x01\x12\x10\n\x08\x46\x65\x65Payer\x18\n \x01(\x0c\x42\x07\n\x05_Time\"T\n\x08\x41rgument\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x06String\x18\x02 \x01(\tH\x00\x12\x0e\n\x04UInt\x18\x03 \x01(\x04H\x00\x12\x0f\n\x05\x46loat\x18\x04 \x01(\x01H\x00\x42\x07\n\x05Value\"E\n\x11TransactionResult\x12\x0e\n\x06Status\x18\x01 \x01(\t\x12\x0f\n\x07Success\x18\x02 \x01(\x08\x12\x0f\n\x07Message\x18\x03 \x01(\t\"\x9f\x01\n\x07Receipt\x12\x0e\n\x06Result\x18\x01 \x01(\t\x12\x1a\n\x12\x45nergyPenaltyTotal\x18\x02 \x01(\x03\x12\x11\n\tEnergyFee\x18\x03 \x01(\x03\x12\x18\n\x10\x45nergyUsageTotal\x18\x04 \x01(\x03\x12\x19\n\x11OriginEnergyUsage\x18\x05 \x01(\x03\x12\x10\n\x08NetUsage\x18\x06 \x01(\x03\x12\x0e\n\x06NetFee\x18\x07 \x01(\x03\"\xbe\x02\n\x08\x43ontract\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x18\n\x10\x45xecutionResults\x18\x02 \x03(\x0c\x12\x0c\n\x04Type\x18\x03 \x01(\t\x12\x0f\n\x07TypeUrl\x18\x04 \x01(\t\x12*\n\tArguments\x18\x05 \x03(\x0b\x32\x17.tron_messages.Argument\x12@\n\x14InternalTransactions\x18\x06 \x03(\x0b\x32\".tron_messages.InternalTransaction\x12\x1f\n\x04Logs\x18\x07 \x03(\x0b\x32\x11.evm_messages.Log\x12\"\n\x05Trace\x18\x08 \x01(\x0b\x32\x13.evm_messages.Trace\x12\x35\n\x0eRewardWithdraw\x18\t \x01(\x0b\x32\x1d.tron_messages.RewardWithdraw\"4\n\x16\x43\x61ncelUnfreezeV2Amount\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x03\"C\n\x03Log\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x12\x0e\n\x06Topics\x18\x03 \x03(\x0c\x12\r\n\x05Index\x18\x04 \x01(\x05\"/\n\tCallValue\x12\x11\n\tCallValue\x18\x01 \x01(\x03\x12\x0f\n\x07TokenId\x18\x02 \x01(\t\"\xa0\x01\n\x13InternalTransaction\x12\x15\n\rCallerAddress\x18\x01 \x01(\x0c\x12\x0c\n\x04Note\x18\x02 \x01(\t\x12\x19\n\x11TransferToAddress\x18\x03 \x01(\x0c\x12,\n\nCallValues\x18\x04 \x03(\x0b\x32\x18.tron_messages.CallValue\x12\x0c\n\x04Hash\x18\x05 \x01(\x0c\x12\r\n\x05Index\x18\x06 \x01(\x05\"2\n\x0eRewardWithdraw\x12\x10\n\x08Receiver\x18\x01 \x01(\x0c\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x04\"\xc6\x01\n\x0bTransaction\x12\x30\n\x06Header\x18\x01 \x01(\x0b\x32 .tron_messages.TransactionHeader\x12\x30\n\x06Result\x18\x02 \x01(\x0b\x32 .tron_messages.TransactionResult\x12\'\n\x07Receipt\x18\x03 \x01(\x0b\x32\x16.tron_messages.Receipt\x12*\n\tContracts\x18\x04 \x03(\x0b\x32\x17.tron_messages.Contract\"\xc2\x01\n\x0b\x42lockHeader\x12\x0e\n\x06Number\x18\x01 \x01(\x03\x12\x0c\n\x04Hash\x18\x02 \x01(\x0c\x12\x11\n\tTimestamp\x18\x03 \x01(\x03\x12\x12\n\nParentHash\x18\x04 \x01(\x0c\x12\x14\n\x0cParentNumber\x18\x05 \x01(\x03\x12\x0f\n\x07Version\x18\x06 \x01(\x05\x12\x12\n\nTxTrieRoot\x18\x07 \x01(\x0c\x12\x18\n\x10\x41\x63\x63ountStateRoot\x18\x08 \x01(\x0c\x12\x19\n\x11TransactionsCount\x18\t \x01(\r\"9\n\x07Witness\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\n\n\x02Id\x18\x02 \x01(\x03\x12\x11\n\tSignature\x18\x03 \x01(\x0c\"\x18\n\x05\x43hain\x12\x0f\n\x07\x43hainId\x18\x01 \x01(\x0c\"\xba\x01\n\x0c\x42lockMessage\x12#\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x14.tron_messages.Chain\x12*\n\x06Header\x18\x02 \x01(\x0b\x32\x1a.tron_messages.BlockHeader\x12\'\n\x07Witness\x18\x03 \x01(\x0b\x32\x16.tron_messages.Witness\x12\x30\n\x0cTransactions\x18\x04 \x03(\x0b\x32\x1a.tron_messages.TransactionB!\n\x12io.bitquery.protosB\x0bTronMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron.block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022io.bitquery.protosB\013TronMessage'
  _globals['_TRANSACTIONHEADER']._serialized_start=69
  _globals['_TRANSACTIONHEADER']._serialized_end=267
  _globals['_ARGUMENT']._serialized_start=269
  _globals['_ARGUMENT']._serialized_end=353
  _globals['_TRANSACTIONRESULT']._serialized_start=355
  _globals['_TRANSACTIONRESULT']._serialized_end=424
  _globals['_RECEIPT']._serialized_start=427
  _globals['_RECEIPT']._serialized_end=586
  _globals['_CONTRACT']._serialized_start=589
  _globals['_CONTRACT']._serialized_end=907
  _globals['_CANCELUNFREEZEV2AMOUNT']._serialized_start=909
  _globals['_CANCELUNFREEZEV2AMOUNT']._serialized_end=961
  _globals['_LOG']._serialized_start=963
  _globals['_LOG']._serialized_end=1030
  _globals['_CALLVALUE']._serialized_start=1032
  _globals['_CALLVALUE']._serialized_end=1079
  _globals['_INTERNALTRANSACTION']._serialized_start=1082
  _globals['_INTERNALTRANSACTION']._serialized_end=1242
  _globals['_REWARDWITHDRAW']._serialized_start=1244
  _globals['_REWARDWITHDRAW']._serialized_end=1294
  _globals['_TRANSACTION']._serialized_start=1297
  _globals['_TRANSACTION']._serialized_end=1495
  _globals['_BLOCKHEADER']._serialized_start=1498
  _globals['_BLOCKHEADER']._serialized_end=1692
  _globals['_WITNESS']._serialized_start=1694
  _globals['_WITNESS']._serialized_end=1751
  _globals['_CHAIN']._serialized_start=1753
  _globals['_CHAIN']._serialized_end=1777
  _globals['_BLOCKMESSAGE']._serialized_start=1780
  _globals['_BLOCKMESSAGE']._serialized_end=1966
# @@protoc_insertion_point(module_scope)
