# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tron/token_block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'tron/token_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tron import block_message_pb2 as tron_dot_block__message__pb2
from evm import token_block_message_pb2 as evm_dot_token__block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etron/token_block_message.proto\x12\rtron_messages\x1a\x18tron/block_message.proto\x1a\x1d\x65vm/token_block_message.proto\"\x94\x01\n\x11TokenBlockMessage\x12#\n\x05\x43hain\x18\x01 \x01(\x0b\x32\x14.tron_messages.Chain\x12*\n\x06Header\x18\x02 \x01(\x0b\x32\x1a.tron_messages.BlockHeader\x12.\n\tTransfers\x18\x03 \x03(\x0b\x32\x1b.evm_messages.TokenTransferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tron.token_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TOKENBLOCKMESSAGE']._serialized_start=107
  _globals['_TOKENBLOCKMESSAGE']._serialized_end=255
# @@protoc_insertion_point(module_scope)
