# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: solana/parsed_idl_block_message.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'solana/parsed_idl_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from solana import block_message_pb2 as solana_dot_block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%solana/parsed_idl_block_message.proto\x12\x0fsolana_messages\x1a\x1asolana/block_message.proto\"\xaa\x01\n\x0eParsedArgument\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x10\n\x06String\x18\x03 \x01(\tH\x00\x12\x0e\n\x04UInt\x18\x05 \x01(\x04H\x00\x12\r\n\x03Int\x18\x06 \x01(\x03H\x00\x12\x0e\n\x04\x42ool\x18\x07 \x01(\x08H\x00\x12\x0f\n\x05\x46loat\x18\x08 \x01(\x02H\x00\x12\x0e\n\x04Json\x18\t \x01(\tH\x00\x12\x11\n\x07\x41\x64\x64ress\x18\n \x01(\x0cH\x00\x42\x07\n\x05Value\"\xb3\x01\n\x07Program\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\x0c\x12\x0e\n\x06Parsed\x18\x02 \x01(\x08\x12\x0c\n\x04Json\x18\x03 \x01(\t\x12\x11\n\tSignature\x18\x04 \x01(\x0c\x12\x0c\n\x04Name\x18\x05 \x01(\t\x12\x0e\n\x06Method\x18\x06 \x01(\t\x12\x32\n\tArguments\x18\x07 \x03(\x0b\x32\x1f.solana_messages.ParsedArgument\x12\x14\n\x0c\x41\x63\x63ountNames\x18\x08 \x03(\t\"\xdf\x03\n\x14ParsedIdlInstruction\x12\r\n\x05Index\x18\x01 \x01(\r\x12\r\n\x05\x44\x65pth\x18\x02 \x01(\r\x12\x10\n\x08\x43\x61llPath\x18\x03 \x03(\r\x12\x13\n\x0b\x43\x61llerIndex\x18\x04 \x01(\x05\x12\x17\n\x0f\x41ncestorIndexes\x18\x05 \x03(\r\x12\x19\n\x11\x45xternalSeqNumber\x18\x06 \x01(\r\x12\x19\n\x11InternalSeqNumber\x18\x07 \x01(\r\x12.\n\x07Program\x18\x08 \x01(\x0b\x32\x18.solana_messages.ProgramH\x00\x88\x01\x01\x12*\n\x08\x41\x63\x63ounts\x18\t \x03(\x0b\x32\x18.solana_messages.Account\x12\x0c\n\x04Logs\x18\n \x03(\t\x12\x36\n\x0e\x42\x61lanceUpdates\x18\x0b \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12;\n\x13TokenBalanceUpdates\x18\x0c \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12\x0c\n\x04\x44\x61ta\x18\r \x01(\x0c\x12:\n\x12TokenSupplyUpdates\x18\x0e \x03(\x0b\x32\x1e.solana_messages.BalanceUpdateB\n\n\x08_Program\"\xe5\x02\n\x14ParsedIdlTransaction\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x11\n\tSignature\x18\x02 \x01(\x0c\x12\x32\n\x06Status\x18\x03 \x01(\x0b\x32\".solana_messages.TransactionStatus\x12\x32\n\x06Header\x18\x04 \x01(\x0b\x32\".solana_messages.TransactionHeader\x12;\n\x13TotalBalanceUpdates\x18\x05 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12@\n\x18TotalTokenBalanceUpdates\x18\x06 \x03(\x0b\x32\x1e.solana_messages.BalanceUpdate\x12\x44\n\x15ParsedIdlInstructions\x18\x07 \x03(\x0b\x32%.solana_messages.ParsedIdlInstruction\"\xac\x01\n\x15ParsedIdlBlockMessage\x12,\n\x06Header\x18\x01 \x01(\x0b\x32\x1c.solana_messages.BlockHeader\x12;\n\x0cTransactions\x18\x02 \x03(\x0b\x32%.solana_messages.ParsedIdlTransaction\x12(\n\x07Rewards\x18\x03 \x03(\x0b\x32\x17.solana_messages.Rewardb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'solana.parsed_idl_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PARSEDARGUMENT']._serialized_start=87
  _globals['_PARSEDARGUMENT']._serialized_end=257
  _globals['_PROGRAM']._serialized_start=260
  _globals['_PROGRAM']._serialized_end=439
  _globals['_PARSEDIDLINSTRUCTION']._serialized_start=442
  _globals['_PARSEDIDLINSTRUCTION']._serialized_end=921
  _globals['_PARSEDIDLTRANSACTION']._serialized_start=924
  _globals['_PARSEDIDLTRANSACTION']._serialized_end=1281
  _globals['_PARSEDIDLBLOCKMESSAGE']._serialized_start=1284
  _globals['_PARSEDIDLBLOCKMESSAGE']._serialized_end=1456
# @@protoc_insertion_point(module_scope)
