# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utxo/parsed_block_message.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'utxo/parsed_block_message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from utxo import block_message_pb2 as utxo_dot_block__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1futxo/parsed_block_message.proto\x12\rutxo_messages\x1a\x18utxo/block_message.proto\"x\n\x12ParsedBlockMessage\x12*\n\x06Header\x18\x01 \x01(\x0b\x32\x1a.utxo_messages.BlockHeader\x12\x36\n\x0cTransactions\x18\x02 \x03(\x0b\x32 .utxo_messages.ParsedTransaction\"\xc2\x01\n\x11ParsedTransaction\x12\x30\n\x06Header\x18\x01 \x01(\x0b\x32 .utxo_messages.TransactionHeader\x12\x35\n\x06Inputs\x18\x02 \x03(\x0b\x32%.utxo_messages.ParsedTransactionInput\x12\x37\n\x07Outputs\x18\x03 \x03(\x0b\x32&.utxo_messages.ParsedTransactionOutput\x12\x0b\n\x03\x46\x65\x65\x18\x04 \x01(\x04\"\x85\x01\n\x16ParsedTransactionInput\x12.\n\x05Input\x18\x02 \x01(\x0b\x32\x1f.utxo_messages.TransactionInput\x12;\n\x0bSpentOutput\x18\x03 \x01(\x0b\x32&.utxo_messages.ParsedTransactionOutput\"<\n\x0eMinBlockHeader\x12\x0c\n\x04Hash\x18\x01 \x01(\x0c\x12\x0e\n\x06Height\x18\x02 \x01(\x03\x12\x0c\n\x04Time\x18\x03 \x01(\x03\"\xe9\x01\n\x17ParsedTransactionOutput\x12\x30\n\x06Output\x18\x01 \x01(\x0b\x32 .utxo_messages.TransactionOutput\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\t\x12-\n\nScriptType\x18\x03 \x01(\x0e\x32\x19.utxo_messages.ScriptType\x12\x0e\n\x06Script\x18\x04 \x01(\x0c\x12\x0f\n\x07ReqSigs\x18\x05 \x01(\r\x12\r\n\x05Value\x18\x06 \x01(\x04\x12,\n\x05\x42lock\x18\x07 \x01(\x0b\x32\x1d.utxo_messages.MinBlockHeader*\xa9\x01\n\nScriptType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06PUBKEY\x10\x01\x12\x0e\n\nPUBKEYHASH\x10\x02\x12\x0e\n\nSCRIPTHASH\x10\x03\x12\x0c\n\x08MULTISIG\x10\x04\x12\x0c\n\x08NULLDATA\x10\x05\x12\x16\n\x12WITNESS_V0_KEYHASH\x10\x06\x12\x19\n\x15WITNESS_V0_SCRIPTHASH\x10\x07\x12\x13\n\x0fWITNESS_UNKNOWN\x10\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utxo.parsed_block_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SCRIPTTYPE']._serialized_start=830
  _globals['_SCRIPTTYPE']._serialized_end=999
  _globals['_PARSEDBLOCKMESSAGE']._serialized_start=76
  _globals['_PARSEDBLOCKMESSAGE']._serialized_end=196
  _globals['_PARSEDTRANSACTION']._serialized_start=199
  _globals['_PARSEDTRANSACTION']._serialized_end=393
  _globals['_PARSEDTRANSACTIONINPUT']._serialized_start=396
  _globals['_PARSEDTRANSACTIONINPUT']._serialized_end=529
  _globals['_MINBLOCKHEADER']._serialized_start=531
  _globals['_MINBLOCKHEADER']._serialized_end=591
  _globals['_PARSEDTRANSACTIONOUTPUT']._serialized_start=594
  _globals['_PARSEDTRANSACTIONOUTPUT']._serialized_end=827
# @@protoc_insertion_point(module_scope)
